@@ -28,17 +28,16 @@ $computype = "linear";
 # THESE OPTIONS ARE ON THE WAY TO BE DISCARDED AND BECOME OBSOLETE. ONLY "linear will remain".
 # WHEN UNSPECIFIED, THE DEFAULT IS "linear".
 
-$calcprocedure = "basic";
-#$calcprocedure = "basic";
-#$calcprocedure = "test";
-#$calcprocedure = "simplified";
-#$calcprocedure = "incomplete";
-#$calcprocedure = "alternative";
-# THESE CALCULATION OPTIONS REGARD THE IRRADIANCES. THEY ARE: "test", incomplete", "alternative", "simplified", "basic", "complete".
-# (SEE SUBROUTINE "pursue").
+@calcprocedures = ( "simplified" );
+# The options are the following:
+# "simplified", "incomplete", "basic", "main", "alternative", "complete", "spreaddiff".
+# "main", "alternative", "complete" and "spreaddiff" can be combined with the other options. 
+# The others can't. "basic" also can be combined with the others: it can be used in place of "alternative".
+# "spreaddiff"c CAN'T BE USED ALONE.
 # THE "incomplete" OPTION IS UNSATISFACTORY AND ON THE WAY TO BECOME OBSOLETE.
-# WITH THE "complete", "alternative" and "test" option, both $bounceambnum and $bouncemaxnum must be assigned a value higher than 0.
-# WHEN A $calcprocedure VALUE IS ABSENT, IT DEFAULTS TO "simplified".
+# MORE THAN ONE OPTION MAY CO-EXIST.
+# WITH THE "complete", "alternative" and "main" option, both $bounceambnum and $bouncemaxnum must be assigned a value higher than 0.
+# WHEN NO @calcprocedures VALUE IS PRESENT, THE PROGRAM DEFAULTS TO "simplified".
 
 %specularratios = ( reflector => 1 );
 #%specularratios = ( totaldirect => 1 );
@@ -53,7 +52,13 @@ $calcprocedure = "basic";
 # EXAMPLE: %specularratios = ( totaldirect => 1 );
 # (SEE SUBROUTINE "pursue").
 
-$skycondition = "intermediate";
+%skycondition = ( 1=> "clear", 2=> "clear", 3=> "clear", 4=> "clear", 5=> "clear", 6=> "clear", 7=> "clear", 8=> "clear", 
+	9=> "clear", 10=> "clear", 11=> "clear", 12=> "clear" );
+# PREVAILING CONDITION OF THE SKY FOR EACH MONTH, EXPRESSED WITH ITS NUMBER.
+# THE OPTIONS ARE: "clear", "cloudy" and "overcast".
+# IF NO VALUE IS SPECIFIED, THE DEFAULT IS "clear".
+
+
 
 
 
